'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var colorette = require('colorette');
var sade = require('sade');
var schema = require('resume-schema');
var util = require('util');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return n;
}

var sade__default = /*#__PURE__*/_interopDefaultLegacy(sade);
var schema__default = /*#__PURE__*/_interopDefaultLegacy(schema);

const pkg = /*#__PURE__*/require('../package.json');

const cli = /*#__PURE__*/sade__default["default"](pkg.name).version(pkg.version);
cli.command('render [filename]', 'Render resume', {
  alias: 'export',
  default: true
}).option('-o, --output', 'Output filename', 'resume.html').option('-t, --theme', 'Theme to use').action(async (filename = 'resume.json', {
  output,
  theme
}) => {
  var _resume$meta;

  const resume = JSON.parse(await fs.promises.readFile(filename, 'utf-8'));
  const themeName = theme != null ? theme : resume == null ? void 0 : (_resume$meta = resume.meta) == null ? void 0 : _resume$meta.theme;

  if (!themeName) {
    console.error(`No theme to use. Please specify one via the ${colorette.yellow('--theme')} option or the ${colorette.yellow('.meta.theme')} field of your resume.`);
    process.exitCode = 1;
    return;
  }

  let themeModule;

  try {
    themeModule = await (function (t) { return Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(t)); }); })(themeName);
  } catch {
    console.error(`Could not load theme ${colorette.yellow(themeName)}. Is it installed?`);
    process.exitCode = 1;
    return;
  }

  const rendered = await render(resume, themeModule);
  await fs.promises.writeFile(output, rendered);
  console.log(`You can find your rendered resume at ${colorette.yellow(output)}. Nice work! 🚀`);
});
cli.command('init [filename]', 'Create sample resume', {
  alias: 'create'
}).action(async (filename = 'resume.json') => {
  await init(filename);
  console.log(`Done! Start editing ${colorette.yellow(filename)} now, and run the ${colorette.yellow('render')} command when you are ready. 👍`);
});
cli.command('validate [filename]', 'Validate resume').action(async (filename = 'resume.json') => {
  try {
    await validate(filename);
    console.log(`Your ${colorette.yellow(filename)} looks amazing! ✨`);
  } catch (err) {
    if (!Array.isArray(err)) {
      throw err;
    }

    console.error(`Uh-oh! The following errors were found in ${colorette.yellow(filename)}:\n`);
    err.forEach(err => console.error(` ${colorette.red(`❌ ${err.message}`)} at ${colorette.yellow(err.path)}.`));
    process.exitCode = 1;
  }
});

const init = filename => {
  const resume = require('resume-schema/sample.resume.json');

  return fs.promises.writeFile(filename, JSON.stringify(resume, undefined, 2));
};

const render = (resume, theme) => theme.render(resume);

const schemaValidate = /*#__PURE__*/util.promisify(schema__default["default"].validate);
const validate = async filename => {
  const resume = await fs.promises.readFile(filename, 'utf-8');
  return schemaValidate(JSON.parse(resume));
};

exports.cli = cli;
exports.init = init;
exports.render = render;
exports.validate = validate;
//# sourceMappingURL=resumed.cjs.development.js.map
